@@ -12,7 +12,7 @@ from matplotlib.figure import Figure
 # type aliases
 
 if TYPE_CHECKING:
-    from typing import Any, Final, TypeAlias, cast
+    from typing import Final, TypeAlias
 
     from matplotlib.axes import Axes
     from numpy.typing import NDArray
@@ -56,7 +56,7 @@ def register_colormap(
     name: str,
     *,
     color_dict: ColorDict | None = None,
-    colors: np.ndarray | None = None,
+    colors: NDArray[np.floating] | None = None,
 ) -> tuple[Colormap, Colormap]:
     name = prefix_name(name)
 
@@ -85,7 +85,7 @@ def register_colormap(
 graySCALE_CONVERSION_SPACE = "JCh"
 
 
-def to_grayscale(sRGB1: np.ndarray) -> np.ndarray:
+def to_grayscale(sRGB1: NDArray[np.floating]) -> NDArray[np.floating]:
     # this is adapted from viscm 0.8
     from colorspacious import cspace_converter  # type: ignore
 
@@ -97,22 +97,22 @@ def to_grayscale(sRGB1: np.ndarray) -> np.ndarray:
     return np.clip(_JCh_to_sRGB1(JCh), 0, 1)
 
 
-def show_cmap(ax: Axes, rgb: np.ndarray) -> None:
+def show_cmap(ax: Axes, rgb: NDArray[np.floating]) -> None:
     # this is adapted from viscm 0.8
     ax.imshow(rgb[np.newaxis, ...], aspect="auto")
 
 
-def get_rgb(cmap: Colormap) -> np.ndarray:
+def get_rgb(cmap: Colormap) -> NDArray[np.floating]:
     # this is adapted from viscm 0.8
     from matplotlib.colors import ListedColormap
 
-    RGB: np.ndarray[Any, Any]
+    rgb: NDArray[np.floating]
     if isinstance(cmap, ListedColormap) and cmap.N >= 100:
-        RGB = np.asarray(cmap.colors)[:, :3]
+        rgb = np.asarray(cmap.colors)[:, :3]
     else:
         x = np.linspace(0, 1, 155)
-        RGB = cmap(x)[:, :3]
-    return RGB
+        rgb = cmap(x)[:, :3]
+    return rgb
 
 
 def create_cmap_overview(
@@ -156,26 +156,29 @@ def create_cmap_overview(
         raise ValueError(f"Received invalid or empty subset: {subset}")
 
     # scale the image size by the number of cmaps
-    fig = Figure(figsize=(6, 2.6 * len(cmaps) / 10.0))
-    axes = fig.subplots(nrows=len(cmaps))
-    if TYPE_CHECKING:
-        axes = cast(NDArray, axes)
+    fig = Figure(figsize=(6, 0.26 * len(cmaps)))
+    axes: list[Axes]
+    if len(cmaps) == 1:
+        axes = [fig.subplots()]
+    else:
+        axes = list(fig.subplots(nrows=len(cmaps)))
 
-    for name, ax in zip(cmaps, axes, strict=False):
+    for name, ax in zip(cmaps, axes, strict=True):
         RGBs = [get_rgb(mpl.colormaps[name])]
         _axes = [ax]
         if with_grayscale:
             RGBs.append(to_grayscale(RGBs[0]))
-            _axes.append(ax.inset_axes([0, 1, 0.999999, 0.3]))
+            _axes.append(ax.inset_axes((0, 1, 0.999999, 0.3)))
 
-        for rgb, _ax in zip(RGBs, _axes, strict=False):
+        for rgb, _ax in zip(RGBs, _axes, strict=True):
             _ax.axis("off")
             show_cmap(_ax, rgb)
         ax.text(
             ax.get_xlim()[1] * 1.02, 0, name.removeprefix(_CMYT_PREFIX), fontsize=10
         )
 
-    fig.tight_layout(h_pad=0.2)
+    if len(cmaps) > 1:
+        fig.tight_layout(h_pad=0.2)
     fig.subplots_adjust(top=0.9, bottom=0.05, right=0.85, left=0.05)
     if filename is not None:
         fig.savefig(os.fspath(filename), dpi=200)
