@@ -31,8 +31,8 @@ viscm_parameters = {
     "max_Jp": 96.5975103734,
 }
 
-luts = (
-    np.array(
+luts = np.transpose(
+    (
         [
             0.02379297,
             0.0261157,
@@ -290,9 +290,7 @@ luts = (
             0.9722811,
             0.97360166,
             0.97499094,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.01131879,
             0.01391783,
@@ -550,9 +548,7 @@ luts = (
             0.93539672,
             0.94119732,
             0.94701577,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.02001135,
             0.02410049,
@@ -810,7 +806,6 @@ luts = (
             0.92805132,
             0.93660318,
             0.9448656,
-        ]
-    ),
-    np.ones(256),
+        ],
+    )
 )
