@@ -22,8 +22,8 @@ viscm_parameters = {
     "max_Jp": 82.1875,
 }
 
-luts = (
-    np.array(
+luts = np.transpose(
+    (
         [
             0.01845663,
             0.01940818,
@@ -281,9 +281,7 @@ luts = (
             0.91657895,
             0.92518702,
             0.93347579,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.14549808,
             0.14959758,
@@ -541,9 +539,7 @@ luts = (
             0.67282641,
             0.67266658,
             0.67286793,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.31784919,
             0.31399639,
@@ -801,7 +797,6 @@ luts = (
             0.97849108,
             0.98057884,
             0.98147471,
-        ]
-    ),
-    np.ones(256),
+        ],
+    )
 )
