@@ -13,9 +13,7 @@ _kamae_red = (
     / 255.0
 )
 _kamae_grn = (
-    np.minimum(
-        255, 70.0 * np.sin(8.7 * (_vs**1.26) - 2.418) + 151.7 * _vs**0.5 + 70.0
-    )
+    np.minimum(255, 70.0 * np.sin(8.7 * (_vs**1.26) - 2.418) + 151.7 * _vs**0.5 + 70.0)
     / 255.0
 )
 _kamae_blu = (
