@@ -1,6 +1,7 @@
-import matplotlib.pyplot as plt
+import matplotlib as mpl
 import numpy as np
 import pytest
+from matplotlib.figure import Figure
 
 import cmyt
 from cmyt._utils import cmyt_cmaps, prefix_name
@@ -25,9 +26,10 @@ def example_data():
 @mpl_compare
 @pytest.mark.parametrize("name", cmyt_cmaps)
 def test_from_str(name, example_data):
-    fig, axes = plt.subplots(ncols=2, figsize=(12, 4))
+    fig = Figure(figsize=(12, 4))
+    axes = fig.subplots(ncols=2)
     pname = prefix_name(name)
-    for cmap, ax in zip([pname, f"{pname}_r"], axes):
+    for cmap, ax in zip([pname, f"{pname}_r"], axes, strict=True):
         ax.set_title(cmap)
         im = ax.imshow(example_data, cmap=cmap)
         fig.colorbar(im, ax=ax)
@@ -37,8 +39,9 @@ def test_from_str(name, example_data):
 @mpl_compare
 @pytest.mark.parametrize("name", cmyt_cmaps)
 def test_from_obj(name, example_data):
-    fig, axes = plt.subplots(ncols=2, figsize=(12, 4))
-    for cmap, ax in zip([name, f"{name}_r"], axes):
+    fig = Figure(figsize=(12, 4))
+    axes = fig.subplots(ncols=2)
+    for cmap, ax in zip([name, f"{name}_r"], axes, strict=True):
         ax.set_title(cmap)
         im = ax.imshow(example_data, cmap=getattr(cmyt, cmap))
         fig.colorbar(im, ax=ax)
@@ -48,4 +51,4 @@ def test_from_obj(name, example_data):
 @pytest.mark.parametrize("name", cmyt_cmaps)
 def test_cmap_name_attr(name):
     assert getattr(cmyt, name).name == name
-    assert plt.get_cmap(f"cmyt.{name}").name == prefix_name(name)
+    assert mpl.colormaps[f"cmyt.{name}"].name == prefix_name(name)
